-- logic
local digits = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
function base62(n)
   local t = {}
   repeat
      local d = (n % 62) + 1
      n = math.floor(n / 62)
      table.insert(t, 1, digits:sub(d,d))
   until n == 0
   return table.concat(t,"")
end

function getPlayerData()
  local p = PlayerLocation:CreateFromUnit('player')
  local name = C_PlayerInfo.GetName(p)
  local realm = GetNormalizedRealmName()
  local race = C_CreatureInfo.GetRaceInfo(C_PlayerInfo.GetRace(p)).clientFileString
  return 'realm='..realm..'&name='..name..'&race='..race
end

local url = 'https://classic-twink.github.io/share-items'
function getBankLink()
  local items = ''
  for i = -1,10 do
     for j = 1,24 do
        local _, _, _, _, _, _, link = GetContainerItemInfo(i, j)
        if link ~= nil then
           local id, ench, rand = string.match(link, '|.-|Hitem:(.-):(.-):.:.:(.-):')
           if items == '' then
              items = items..base62(id)
           else
              items = items..','..base62(id)
           end
           if rand ~= '' then items = items..'.'..base62(rand) end
           if ench ~= '' then
              if rand == '' then items = items..'.' end
              items = items..'.'..base62(ench)
           end
        end
     end
  end
  return url..'?type=bank&'..getPlayerData()..'&items='..items
end

local frame = CreateFrame("Frame", "frame", UIParent)
local text = CreateFrame("EditBox", "frame_text", frame)
local comment = CreateFrame("EditBox", "frame_comment", frame)
local scroll = CreateFrame("ScrollFrame", "frame_scroll", frame, "UIPanelScrollFrameTemplate")

-- layout
comment:SetWidth(100)
comment:SetHeight(24)
comment:SetPoint("TOPLEFT", frame, "TOPLEFT", 10, 24)
comment:SetFontObject("GameTooltipTextSmall")
comment:SetText("CTRL+C to copy")
text:SetPoint("CENTER", frame, "CENTER")
text:SetFontObject("GameTooltipTextSmall")
scroll:SetPoint("TOPLEFT", frame, "TOPLEFT", 6, -6)
scroll:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -6, 6)
scroll:SetScrollChild(text)
frame:SetFrameStrata("HIGH")
frame:SetPoint("BOTTOMLEFT", BankFrame, "BOTTOMLEFT", 25, -25)
frame:SetWidth(250)
frame:SetHeight(60)
frame:SetBackdrop({
  bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
  edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
  tile = true,
  tileSize = 16,
  edgeSize = 16,
  insets = { left = 4, right = 4, top = 4, bottom = 4 }
})

-- config
comment:SetAutoFocus(false)
comment:SetMultiLine(false)
comment:EnableMouse(false)
text:SetAutoFocus(false)
text:SetMultiLine(true)
frame:SetClampedToScreen(true)

-- events
function HideUI()
  text:Hide()
  frame:Hide()
  scroll:Hide()
  comment:Hide()
end

function ShowUI()
  text:Show()
  frame:Show()
  scroll:Show()
  comment:Show()
  text:Insert(getBankLink())
end

frame:RegisterEvent("BANKFRAME_OPENED")
frame:RegisterEvent("BANKFRAME_CLOSED")
frame:SetScript("OnEvent", function (data, event)
  if event == "BANKFRAME_OPENED" then ShowUI() end
  if event == "BANKFRAME_CLOSED" then HideUI() end
end)

frame:SetScript("OnUpdate", function()
  text:SetWidth(frame:GetWidth() - 13)
  text:SetHeight(frame:GetHeight() - 13)
  scroll:UpdateScrollChildRect()
end)

text:SetScript("OnEscapePressed", HideUI)
text:SetScript("OnEditFocusGained", function () text:HighlightText() end)

HideUI()
